@@ -17,8 +17,8 @@ limitations under the License.
 from django.conf import settings
 from django.core.management import call_command
 from django.core.management.commands import test
-from django_coverage import settings as coverage_settings
 
+from django_coverage import settings as coverage_settings
 
 class Command(test.Command):
     help = ("Runs the test suite for the specified applications, or the "
@@ -27,9 +27,12 @@ class Command(test.Command):
 
     def handle(self, *test_labels, **options):
         """
-        Replaces the original test runner with the coverage test runner.
-        Then, call the test command. This plays well with apps that
-        override the test command, such as South.
+        Replaces the original test runner with the coverage test runner, but
+        keeps track of what the original runner was so that the coverage
+        runner can inherit from it.  Then, call the test command. This
+        plays well with apps that override the test command, such as South.
         """
+        coverage_settings.ORIG_TEST_RUNNER = settings.TEST_RUNNER
         settings.TEST_RUNNER = coverage_settings.COVERAGE_TEST_RUNNER
         call_command('test', *test_labels, **options)
+
